@@ -292,6 +292,7 @@ static const char *drmSymbols[] = {
     "drmCtlUninstHandler",
     "drmCommandNone",
     "drmCommandWrite",
+    "drmCommandWriteRead",
     "drmFreeVersion",
     "drmGetInterruptFromBusID",
     "drmGetLibVersion",
@@ -1450,8 +1451,8 @@ static Bool VIAEnterVT(int scrnIndex, int flags)
 
 
 #ifdef XF86DRI
-    kickVblank(pScrn);
     if (pVia->directRenderingEnabled) {
+        kickVblank(pScrn);
 	VIADRIRingBufferInit(pScrn);
 	DRIUnlock(screenInfo.screens[scrnIndex]);
     }
@@ -2233,6 +2234,7 @@ VIAAdjustFrame(int scrnIndex, int x, int y, int flags)
 
     if (pVia->pVbe) {
 	ViaVbeAdjustFrame(scrnIndex, x, y, flags);
+	VIAVidAdjustFrame(pScrn, x, y);
 	return;
     }
 
